# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import datetime
from django.utils.timezone import utc


class Migration(migrations.Migration):

    dependencies = [
        ('urltrace', '0002_initial_data'),
    ]

    operations = [
        migrations.AlterField(
            model_name='urltracegroup',
            name='group_name',
            field=models.CharField(unique=True, max_length=200),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations

def load_first_data(apps, schema_editor):
    UrlTraceGroup = apps.get_model('urltrace', 'UrlTraceGroup')
    UrlTraceGroup.objects.create(group_name="general",
                                 description="general group of urls")

class Migration(migrations.Migration):

    dependencies = [
        ('urltrace', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(load_first_data),
    ]


# -*- coding: utf-8 -*-
from . import constants
from django.db import models
from django.utils import timezone


class UrlTraceGroup(models.Model):

    group_name = models.CharField(
        max_length=200,
        unique=True
    )

    description = models.TextField(
        blank=True,
    )

    is_active = models.SmallIntegerField(
        choices=constants.STATUS_CHOICES,
        default=constants.STATUS_TRUE
    )

    created_at = models.DateTimeField(
        default=timezone.now(),
        editable=False,
    )

    updated_at = models.DateTimeField(
        default=timezone.now(),
        editable=False,
    )

    def __str__(self):
        return "{}".format(self.group_name)


class UrlTrace(models.Model):

    url_trace = models.TextField(unique=True)

    url_trace_group = models.ForeignKey(UrlTraceGroup)

    description = models.TextField(
        blank=True,
    )

    is_active = models.SmallIntegerField(
        choices=constants.STATUS_CHOICES,
        default=constants.STATUS_TRUE
    )

    created_at = models.DateTimeField(
        default=timezone.now(),
        editable=False,
    )

    updated_at = models.DateTimeField(
        default=timezone.now(),
        editable=False,
    )

    def __str__(self):
        return "{}".format(self.url_trace)





from django.contrib import admin
from models import UrlTrace,UrlTraceGroup


class UrlTraceAdmin(admin.ModelAdmin):
    list_filter = ['is_active','url_trace_group']
    list_display = ['url_trace', 'url_trace_group', 'is_active','description','description']
    search_fields = ('url_trace', 'url_trace_group','description',)

class UrlTraceGroupAdmin(admin.ModelAdmin):
    list_filter = ['is_active']
    list_display = ['group_name', 'is_active','description','description']
    search_fields = ('group_name', 'description',)

admin.site.register(UrlTrace,UrlTraceAdmin)
admin.site.register(UrlTraceGroup, UrlTraceGroupAdmin)


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.test import TestCase,override_settings
from urltrace.models import UrlTrace,UrlTraceGroup
from urltrace import constants
from django.test import Client
from urltrace.middleware import  UrlTraceMiddleware

@override_settings(ROOT_URLCONF='urltrace.tests.urls')
@override_settings(DEBUG=True)
class ActionsTestCase(TestCase):
    def setUp(self):
        # create a group name
        url_trace_group = UrlTraceGroup(
            group_name="group_name_test",
            description="group name test"
        )
        url_trace_group.save()
        url_trace = UrlTrace(
            url_trace="/url_trace/1",
            url_trace_group=url_trace_group,
            description="url trace test 1 group name group_name_test"
        )
        url_trace.save()
        # registro del group trace general
        url_trace_group = UrlTraceGroup.objects.get(id=constants.DEFAULT_REGISTER)
        url_trace = UrlTrace(
            url_trace="/url_trace/2",
            url_trace_group=url_trace_group,
            description="url trace test 2 group name general"
        )
        url_trace.save()

        self.middleware = UrlTraceMiddleware()
        self.client = Client()
        self.request = self.client.get('/url_trace3/')

        pass

    def test_register_url_trace(self):
        url_trace = UrlTrace.objects.get(url_trace="/url_trace/1")
        print url_trace.description + " - " + url_trace.url_trace_group.group_name

        url_trace = UrlTrace.objects.get(url_trace="/url_trace/2")
        print url_trace.description + " - " + url_trace.url_trace_group.group_name

        pass

    def test_url_trace_middleware(self):
        self.request._closable_objects[0].META["HTTP_REFERER"] = "m.facebook.com/"
        self.request._closable_objects[0].META["HTTP_HOST"] = "www.crehana.com/"

        self.middleware.process_request(self.request._closable_objects[0])
        url_trace = UrlTrace.objects.filter(url_trace="m.facebook.com/")
        if len(url_trace)>0:
            print "Url create : " + url_trace[0].url_trace + ":" + url_trace[0].url_trace_group.group_name

        pass


# -*- coding: utf-8 -*-
from urltrace.models import UrlTrace,UrlTraceGroup
from urltrace import constants

def register_url_trace(url_trace):
    #validate url exist in cache
    list_url_trace = UrlTrace.objects.filter(url_trace=url_trace)

    if len(list_url_trace)<=0:
        # update views in database
        url_trace_group_default = UrlTraceGroup.objects.get(id=constants.DEFAULT_REGISTER)
        objUrlTrace = UrlTrace(url_trace=url_trace, url_trace_group=url_trace_group_default)
        objUrlTrace.save()
        name_group_trace = url_trace_group_default.group_name
    else:
        name_group_trace = list_url_trace[0].url_trace_group.group_name

    return name_group_trace


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import datetime
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='UrlTrace',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('url_trace', models.TextField(unique=True)),
                ('description', models.TextField(blank=True)),
                ('is_active', models.SmallIntegerField(default=1, choices=[(1, b'True'), (2, b'False')])),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='UrlTraceGroup',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('group_name', models.TextField(unique=True)),
                ('description', models.TextField(blank=True)),
                ('is_active', models.SmallIntegerField(default=1, choices=[(1, b'True'), (2, b'False')])),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='urltrace',
            name='url_trace_group',
            field=models.ForeignKey(to='urltrace.UrlTraceGroup'),
            preserve_default=True,
        ),
    ]



from urltrace.actions import register
import urlparse

class UrlTraceMiddleware():

    def process_request(self, request):
        origin = ""
        if request.GET.get("utm_source"):
            origin = request.GET.get("utm_source")
        else:
            if "HTTP_HOST" in request.META:
                url_host = request.META['HTTP_HOST']
                if 'HTTP_REFERER' in request.META:
                    if url_host in request.META['HTTP_REFERER']:
                        origin = request.META['HTTP_REFERER'].split(url_host)[1]
                    else:
                        origin = request.META['HTTP_REFERER']

        if origin <> "" and origin[0] <> "/":
            netloc = urlparse.urlparse(origin).netloc
            if netloc <> "":
                origin = netloc
            # register the origin and asign group
            register.register_url_trace(origin)

            try:
                request.session["name_group_trace"] = origin
            except AttributeError:
                request.session = {"name_group_trace" : origin}

        pass
